# CWL Worflows processor to generate PlantUML diagrams

This project aims to deliver a simple yet powerful CLI tool to ingest [CWL Workflows](https://www.commonwl.org/) and generate [PantUM diagrams](https://plantuml.com/).

## Contribute

Submit a [Github issue](https://github.com/Terradue/cwl2puml/issues) if you have comments or suggestions.

## Documentation

See the documentation at https://Terradue.github.io/cwl2puml/

## License

[![License: CC BY-SA 4.0](https://img.shields.io/badge/License-CC_BY--SA_4.0-lightgrey.svg)](https://creativecommons.org/licenses/by-sa/4.0/)
